@@ -17,6 +17,7 @@ geom_mean <- function(x, na.rm = TRUE) {
 #' @param df tibble
 #' @param y value
 #' @param x sample test group
+#' @param trans scale transformation
 #' @param paired paired samples or not
 #' @param .by super-group
 #' @param method test method, 'wilcoxon' as default
@@ -27,19 +28,36 @@ geom_mean <- function(x, na.rm = TRUE) {
 #' @export
 #'
 #' @examples stat_test(mini_diamond, y = price, x = cut, .by = clarity)
-stat_test <- function(df, y, x, paired = FALSE, alternative = "two.sided",
+stat_test <- function(df, y, x, trans = "identity",
+                      paired = FALSE, alternative = "two.sided",
                       method = "wilcoxon", .by = NULL, ...) {
   y <- rlang::enquo(y)
   x <- rlang::enquo(x)
   .by <- rlang::enquo(.by)
 
-  # fomular
+  # if the real x column levels not match to factor levels
+  # rstatix will throw an error
+  factor_levels <- df[[quo_name(x)]] %>% levels()
+  real_levels <- df[[quo_name(x)]] %>% unique()
+
+  if (!is.null(factor_levels) &&
+    (length(factor_levels) != length(real_levels))) {
+    stop("please reset the factor levels to match the data!")
+  }
+
+  res <- df
+
+
+  # trans
+  if (trans == "log10") {
+    res <- dplyr::mutate(res, !!y := log10(!!y))
+  }
+
+  # fomula
   fomular_str <- stringr::str_c(rlang::quo_name(y), "~", rlang::quo_name(x))
 
   # super-group
-  if (!rlang::quo_is_null(.by)) {
-    res <- df %>% dplyr::group_by({{ .by }})
-  }
+  res <- res %>% dplyr::group_by({{ .by }})
 
   # test
   if (method == "wilcoxon") {
@@ -47,8 +65,15 @@ stat_test <- function(df, y, x, paired = FALSE, alternative = "two.sided",
       paired = paired,
       alternative = alternative, ...
     )
+  } else if (method == "t") {
+    res <- res %>% rstatix::t_test(stats::as.formula(fomular_str),
+      paired = paired,
+      alternative = alternative, ...
+    )
   }
-  res <- res %>% rstatix::add_significance("p",
+
+  res <- res %>% rstatix::add_significance(
+    "p",
     symbols = c("****", "***", "**", "*", "NS")
   )
 
@@ -66,12 +91,14 @@ stat_test <- function(df, y, x, paired = FALSE, alternative = "two.sided",
 #' @param .by super-group
 #' @param method `'mean'|'median'|'geom_mean'`, the summary method
 #' @param signif_digits fold change signif digits
+#' @param rev_div reverse division
 #'
 #' @return fold change result tibble
 #' @export
 #'
 #' @examples stat_fc(mini_diamond, y = price, x = cut, .by = clarity)
-stat_fc <- function(df, y, x, method = "mean", .by = NULL, signif_digits = 2) {
+stat_fc <- function(df, y, x, method = "mean", .by = NULL,
+                    rev_div = FALSE, signif_digits = 2) {
   y <- rlang::enquo(y)
   x <- rlang::enquo(x)
   .by <- rlang::enquo(.by)
@@ -90,7 +117,7 @@ stat_fc <- function(df, y, x, method = "mean", .by = NULL, signif_digits = 2) {
     stop("choose a method from mean, median and geom_mean")
   }
 
-  df <- df %>% dplyr::summarise("{{y}}" :=  # nolint
+  df <- df %>% dplyr::summarise("{{y}}" := # nolint
     func({{ y }}), .by = c({{ .by }}, {{ x }}))
 
   # full join
@@ -104,7 +131,8 @@ stat_fc <- function(df, y, x, method = "mean", .by = NULL, signif_digits = 2) {
 
   res <- dplyr::full_join(df, df,
     by = by,
-    suffix = c("_1", "_2"), multiple = "all"
+    suffix = c("_1", "_2"), multiple = "all",
+    relationship = "many-to-many"
   )
 
   # fold change
@@ -112,14 +140,21 @@ stat_fc <- function(df, y, x, method = "mean", .by = NULL, signif_digits = 2) {
   ycol2 <- stringr::str_c(rlang::quo_name(y), "_2")
   res <- res %>%
     dplyr::mutate(
-      fc = .data[[ycol1]] / .data[[ycol2]], # nolint
-      fc_fmt = signif_string(.data$fc, signif_digits) %>%
-        stringr::str_c("x")
+      fc = .data[[ycol1]] / .data[[ycol2]]
     )
+  # reverse div
+  if (rev_div) {
+    res <- res %>% dplyr::mutate(fc = 1 / .data[["fc"]])
+  }
+
+  res <- res %>% dplyr::mutate(
+    fc_fmt = signif_string(.data$fc, signif_digits) %>%
+      stringr::str_c("x")
+  )
 
   # remove auxiliary column
   if (rlang::quo_is_null(.by)) {
-    res <- res %>% dplyr::select(-by)
+    res <- res %>% dplyr::select(-tidyselect::all_of(by))
   }
 
   # rename
