@@ -54,45 +54,57 @@ test_that("fancy_count, sort=FALSE", {
 
 test_that("fancy_count, three column", {
   expect_snapshot(
-    fancy_count(mini_diamond, cut, clarity, ext = id)
+    fancy_count(mini_diamond, cut, clarity, ext = id) %>% print(n = Inf)
   )
 })
 
 
 
 test_that("expand_df", {
-  expect_snapshot(fancy_count(mini_diamond, cut, ext = clarity) %>%
-    split_column(name_col = cut, value_col = clarity))
+  expect_snapshot(
+    fancy_count(mini_diamond, cut, ext = clarity) %>%
+      split_column(name_col = cut, value_col = clarity) %>%
+      print(n = Inf)
+  )
 })
 
 
 
 test_that("move_row, .after=TRUE", {
-  expect_snapshot(move_row(mini_diamond, 3:5, .after = TRUE))
+  expect_snapshot(move_row(mini_diamond, 3:5, .after = TRUE) %>% print(n = Inf))
 })
 
 test_that("move_row, after last row", {
-  expect_snapshot(move_row(mini_diamond, 3:5, .after = nrow(mini_diamond)))
+  expect_snapshot(
+    move_row(mini_diamond, 3:5, .after = nrow(mini_diamond)) %>% print(n = Inf)
+  )
 })
 
 test_that("move_row, after first row", {
-  expect_snapshot(move_row(mini_diamond, 3:5, .after = 1))
+  expect_snapshot(move_row(mini_diamond, 3:5, .after = 1) %>% print(n = Inf))
 })
 
 test_that("move_row, .before=TRUE", {
-  expect_snapshot(move_row(mini_diamond, 3:5, .before = TRUE))
+  expect_snapshot(
+    move_row(mini_diamond, 3:5, .before = TRUE) %>% print(n = Inf)
+  )
 })
 
 test_that("move_row, beofre first row", {
-  expect_snapshot(move_row(mini_diamond, 3:5, .before = 1))
+  expect_snapshot(
+    move_row(mini_diamond, 3:5, .before = 1) %>% print(n = Inf)
+  )
 })
 
 test_that("move_row, beofre last row", {
-  expect_snapshot(move_row(mini_diamond, 3:5, .before = nrow(mini_diamond)))
+  expect_snapshot(
+    move_row(mini_diamond, 3:5, .before = nrow(mini_diamond)) %>%
+      print(n = Inf)
+  )
 })
 
 test_that("move_row", {
-  expect_snapshot(move_row(mini_diamond, 3:5, .after = 8))
+  expect_snapshot(move_row(mini_diamond, 3:5, .after = 8) %>% print(n = Inf))
 })
 
 
@@ -142,3 +154,22 @@ test_that("ordered_slice, remove dup and NA", {
 test_that("ordered_slice, pass column with duplication", {
   expect_error(ordered_slice(mini_diamond, cut, c("Ideal")))
 })
+
+test_that("hist_bins", {
+  vector <- dplyr::pull(mini_diamond, price, id)
+  expect_error(hist_bins(c("a", "b")))
+  expect_snapshot(hist_bins(vector) %>% print(n = Inf))
+})
+
+test_that("hist_bins, lim", {
+  vector <- dplyr::pull(mini_diamond, price, id)
+  expect_error(hist_bins(vector, lim = c(2000, 18000)))
+  expect_snapshot(hist_bins(vector, lim = c(0, 20000)) %>% print(n = Inf))
+})
+
+test_that("hist_bins, breaks", {
+  vector <- dplyr::pull(mini_diamond, price, id)
+  expect_error(hist_bins(vector, breaks = seq(2000, 18000, length.out = 11)))
+  expect_snapshot(hist_bins(vector, breaks = seq(0, 20000, length.out = 11)) %>%
+    print(n = Inf))
+})
